# lipidoz
Python utility for determination of lipid double bond position location from OzID data

#### Contributors:
- Dylan Ross (dylan.ross@pnnl.gov)
- Aivett Bilbao (aivett.bilbao@pnnl.gov)
- Joon-Yong Lee (junyoni@gmail.com)
- Xueyun Zheng (xueyun.zheng@pnnl.gov)

<hr>


Documentation is available at https://lipidoz.readthedocs.io/


<hr>

Beta Release (with GUI executables) available at: https://github.com/PNNL-m-q/lipidoz/releases/tag/v1.0.0

<hr>

Demonstration of GUI application with data for Ultimate SPLASH lipid standards available here: https://zenodo.org/record/7636522
